@@ -1,4 +1,4 @@
-import time, uuid, json
+import time, uuid, json, nanoid
 from datetime import datetime, timezone
 
 class Event:
@@ -11,10 +11,13 @@ class Event:
         self.children = []
         self.data.update({
             'log_logger': logger,
-            'timestamp': datetime.now(timezone.utc).isoformat(),
+            'log_start_ns': time.time_ns(),
+            'log_start': datetime.now(timezone.utc).isoformat(),
             'log_operation': op,
-            'log_id': uuid.uuid4().hex
+            'log_id': nanoid.generate()
         })
+        self.data.update(kwargs)
+        self.children = []
 
     def id(self) -> str:
         return self.data['log_id']
